testutil

package
v0.4.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 25, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Overview

Package testutil provides test helper functions for the tryssh project.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateTestConfigFile

func CreateTestConfigFile(t *testing.T, dir string, content string) string

CreateTestConfigFile writes a test configuration file in the given directory.

func CreateTestKnownHosts

func CreateTestKnownHosts(t *testing.T, dir string, content string) string

CreateTestKnownHosts writes a test known_hosts file in the given directory.

func ReadFile

func ReadFile(t *testing.T, path string) string

ReadFile reads and returns the contents of a file in tests.

func TempDir

func TempDir(t *testing.T) string

TempDir creates and returns a temporary directory for tests.

Types

This section is empty.

Jump to