Documentation
¶
Overview ¶
Package testutil provides test helper functions for the tryssh project.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateTestConfigFile ¶
CreateTestConfigFile writes a test configuration file in the given directory.
func CreateTestKnownHosts ¶
CreateTestKnownHosts writes a test known_hosts file in the given directory.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.